@@ -20,8 +20,8 @@ def get_keywords(file_path, max_ngram_size=3, deduplication_threshold=0.9, numOf
         text = ""
         # loop through each page and extract the text
         for page_num in range(num_pages):
-            page_obj = pdf_reader.getPage(page_num)
-            text += page_obj.extractText()
+            page_obj = pdf_reader.pages[page_num]
+            text += page_obj.extract_text()
 
         # if no text was extracted, use textract to extract text from scanned PDFs
         if not text:
